package com.xynet.marketing.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xynet.marketing.entity.Merc;
import com.xynet.marketing.mapper.MercMapper;
import com.xynet.marketing.service.MercService;
import com.xynet.marketing.utils.Emptys;
import com.xynet.marketing.utils.collections.map.JHashMap;
import com.xynet.marketing.utils.collections.map.JMap;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 商户服务实现类
 * @author hechunping
 * @date 2025/1/18
 */
@Service
public class MercServiceImpl extends ServiceImpl<MercMapper, Merc> implements MercService {

    private LambdaQueryWrapper<Merc> commonQueryWrapper(JMap<String,Object> param) {
        LambdaQueryWrapper<Merc> lqw = new LambdaQueryWrapper<Merc>()
                .eq(Emptys.check(param.getInt("id")), Merc::getId, param.getInt("id"))
                ;
        return lqw;
    }
    @Override
    public Map<String, Object> obj(JMap<String, Object> param) {
        LambdaQueryWrapper<Merc> lqw = commonQueryWrapper(param).last("limit 1");
        Merc obj = getOne(lqw);
        return JHashMap.copy(obj);
    }

    @Override
    public void saveOrUpdate(JMap<String, Object> param) {
        Merc save = BeanUtil.copyProperties(param, Merc.class);
        if(Emptys.check(save.getId())){
            updateById(save);
        }else{
            save(save);
        }
    }

    @Override
    public List<Map<String, Object>> list(JMap<String, Object> param) {
        LambdaQueryWrapper<Merc> lqw = commonQueryWrapper(param).orderByAsc(Merc::getId);
        List<Merc> list = list(lqw);
        return JHashMap.copy(list);
    }

    @Override
    public Page<Map<String, Object>> page(JMap<String, Object> param) {
        LambdaQueryWrapper<Merc> lqw = commonQueryWrapper(param).orderByAsc(Merc::getId);
        Page<Merc> page = new Page<>(param.getInt("pageNum"), param.getInt("pageSize"), true);
        Page<Merc> list = page(page, lqw);
        return JHashMap.copy(list);
    }

    @Override
    public Integer thirdMercIdToMercId(String providerId, String thirdMercId) {
        LambdaQueryWrapper<Merc> lqw = new LambdaQueryWrapper<Merc>()
                .select(Merc::getId)
                .eq(Merc::getProviderId, providerId)
                .eq(Merc::getThirdMercId, thirdMercId)
                .last("limit 1");
        Merc merc = getOne(lqw);
        if (!Emptys.check(merc)) {
            throw new RuntimeException("商户不存在");
        }
        return merc.getId();
    }
}
