package com.xynet.marketing.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xynet.marketing.entity.Promotion;
import com.xynet.marketing.mapper.PromotionMapper;
import com.xynet.marketing.service.MercProjectDeviceService;
import com.xynet.marketing.service.MercProjectGoodsService;
import com.xynet.marketing.service.PromotionService;
import com.xynet.marketing.service.factory.promotion.PromotionFactory;
import com.xynet.marketing.utils.Emptys;
import com.xynet.marketing.utils.FactoryUtils;
import com.xynet.marketing.utils.collections.map.JHashMap;
import com.xynet.marketing.utils.collections.map.JMap;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 促销活动 服务
 *
 * @author hechunping
 * @date 2025/1/21
 */
@Service
@Slf4j
@AllArgsConstructor
public class PromotionServiceImpl extends ServiceImpl<PromotionMapper, Promotion> implements PromotionService {

    private MercProjectGoodsService goodsService;
    private MercProjectDeviceService deviceService;

    private static String ACT_TYPE = "promotion";

    private LambdaQueryWrapper<Promotion> commonQueryWrapper(JMap<String, Object> param) {
        LambdaQueryWrapper<Promotion> lqw = new LambdaQueryWrapper<Promotion>()
                .eq(Emptys.check(param.getInt("id")), Promotion::getId, param.getInt("id"))
                .eq(Emptys.check(param.getInt("mercId")), Promotion::getMercId, param.getInt("mercId"))
                .eq(Emptys.check(param.getString("status")), Promotion::getStatus, param.getString("status"));
        return lqw;
    }

    @Override
    public Map<String, Object> obj(JMap<String, Object> param) {
        LambdaQueryWrapper<Promotion> lqw = commonQueryWrapper(param).last("limit 1");
        Promotion obj = getOne(lqw);
        if (!Emptys.check(obj)) {
            return null;
        }
        Map<String, Object> vo = JHashMap.copy(obj);
        //反显设备信息
        if (!obj.getIsAllDevice()) {
            List<Map<String, Object>> deviceList = deviceService.listByActId(obj.getId(), ACT_TYPE);
            vo.put("deviceList", deviceList);
        }
        //反显商品信息
        if (!obj.getIsAllGoods()) {
            List<Map<String, Object>> goodsList = goodsService.listByActId(obj.getId(), ACT_TYPE);
            vo.put("goodsList", goodsList);
        }
        return vo;
    }

    @Override
    public Integer saveOrUpdate(JMap<String, Object> param) {
        PromotionFactory promotionFactory = FactoryUtils.getService(PromotionFactory.class, "promotion_base");
        return promotionFactory.saveOrUpdate(param);
    }

    @Override
    public void updateEnableStatus(JMap<String, Object> param) {
        LambdaUpdateWrapper<Promotion> lqw = new LambdaUpdateWrapper<Promotion>()
                .eq(Promotion::getId, param.getInt("id"))
                .eq(Promotion::getMercId, param.getInt("mercId"))
                .set(Promotion::getEnableStatus, param.getBoolean("enableStatus"));
        update(lqw);
    }

    @Override
    public List<Map<String, Object>> list(JMap<String, Object> param) {
        LambdaQueryWrapper<Promotion> lqw = commonQueryWrapper(param).orderByAsc(Promotion::getId);
        List<Promotion> list = list(lqw);
        return JHashMap.copy(list);
    }

    @Override
    public Page<Map<String, Object>> page(JMap<String, Object> param) {
        LambdaQueryWrapper<Promotion> lqw = commonQueryWrapper(param).orderByAsc(Promotion::getId);
        Page<Promotion> page = new Page<>(param.getInt("pageNum"), param.getInt("pageSize"), true);
        Page<Promotion> list = page(page, lqw);
        return JHashMap.copy(list);
    }

    @Override
    public JMap<String, Object> goodsListPrice(JMap<String, Object> param) {
        PromotionFactory promotionFactory = FactoryUtils.getService(PromotionFactory.class, "promotion_base");
        return promotionFactory.goodsListPrice(param);
    }

}
