package com.xynet.marketing.utils.redis.config;

import cn.hutool.core.lang.Console;
import lombok.AllArgsConstructor;
import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.List;

/**
 * redisson配置
 */
@Configuration
@AllArgsConstructor
public class RedissonConfiguration {

    private RedisConfig redisConfig;

    @Bean
    public RedissonClient getRedisson() {
        return redisConfig.getCluster() == null ? single() : cluster();
    }

    /**
     * 单机
     *
     * @return
     */
    private RedissonClient single() {
        Config config = new Config();
        config.useSingleServer()
                .setAddress("redis://" + redisConfig.getHost() + ":" + redisConfig.getPort())
                .setPassword(redisConfig.getPassword());
        return Redisson.create(config);
    }

    /**
     * 集群
     *
     * @return
     */
    private RedissonClient cluster() {
        RedisConfig.cluster cluster = redisConfig.getCluster();
        List<String> nodes = cluster.getNodes();
        List<String> clusterNodes = new ArrayList<>(nodes.size());
        for (String node : nodes) {
            clusterNodes.add("redis://" + node);
        }
        Config config = new Config();
        config.useClusterServers()
                .addNodeAddress(clusterNodes.toArray(new String[clusterNodes.size()]))
                .setPassword(redisConfig.getPassword());
        return Redisson.create(config);
    }
}
